-- =============================================
-- SaveToDB Framework for PostgreSQL
-- Version 8.15, November 7, 2018
--
-- This script upgrades SaveToDB Framework 8.11 to SaveToDB Framework 8.15
--
-- Copyright 2015-2018 Gartle Technology Corporation
-- =============================================

UPDATE xls.handlers SET handler_code = 'TABLE, VIEW, FUNCTION, CODE, HTTP, TEXT, MACRO, CMD, VALUES, RANGE, REFRESH, MENUSEPARATOR, PDF, REPORT, SHOWSHEETS, HIDESHEETS, SELECTSHEET'
    WHERE table_schema = 'xls' AND table_name = 'handlers' AND column_name = 'handler_type' AND event_name = 'ValidationList' AND handler_type = 'VALUES';

CREATE OR REPLACE VIEW xls.queries
AS
SELECT
    t.table_schema
    , t.table_name
    , t.table_type
    , NULL AS table_code
    , NULL AS insert_procedure
    , NULL AS update_procedure
    , NULL AS delete_procedure
    , NULL AS procedure_type
FROM
    information_schema.tables t
WHERE
    NOT t.table_schema IN ('information_schema', 'pg_catalog', 'xls', 'savetodb_dev', 'savetodb_xls')
    AND NOT t.table_name LIKE 'xl_%'
UNION
SELECT
    r.routine_schema AS table_schema
    , r.routine_name AS table_name
    , r.routine_type AS table_type
    , NULL AS table_code
    , NULL AS insert_procedure
    , NULL AS update_procedure
    , NULL AS delete_procedure
    , NULL AS procedure_type
FROM 
    information_schema.routines r
WHERE
    NOT r.routine_schema IN ('information_schema', 'pg_catalog', 'xls', 'savetodb_dev', 'savetodb_xls')
    AND r.routine_type = 'FUNCTION'
    AND NOT (
        r.routine_name LIKE '%_insert'
        OR r.routine_name LIKE '%_update'
        OR r.routine_name LIKE '%_delete'
        OR r.routine_name LIKE '%_merge'
        OR r.routine_name LIKE '%_change'
        OR r.routine_name LIKE 'xl_%'
    )
UNION ALL
SELECT
    o.table_schema
    , o.table_name
    , o.table_type
    , o.table_code
    , o.insert_object as insert_procedure
    , o.update_object as update_procedure
    , o.delete_object as delete_procedure
    , NULL as procedure_type
FROM
    xls.objects o
WHERE
    o.table_type IN ('CODE', 'HTTP', 'TEXT')
    AND o.table_schema IS NOT NULL
    AND o.table_name IS NOT NULL
    AND o.table_code IS NOT NULL
    AND NOT o.table_name LIKE 'xl_%'
ORDER BY
    table_schema
    , table_name;
